Interferogram to Spectrum
=========================

Performs Fast Fourier Transform on an interferogram, including zero filling, apodization and phase correction.

Inputs
    Interferogram
        input interferogram

Outputs
    Spectra
        dataset with spectra
    Phases
        phases